@@ -273,7 +273,7 @@ sienaDataCreate<- function(..., nodeSets=NULL, getDocumentation=FALSE)
 	compositionChange <- vector('list',narg)
 	v1 <- 0; v2 <- 0; v3 <- 0; v4 <- 0; v5 <- 0; v6 <- 0
 	for (i in seq(along = dots))
-		switch(class(dots[[i]]),
+		switch(class(dots[[i]])[1],
 			   sienaDependent = {
 				   if (attr(dots[[i]],'sparse'))
 				   {
@@ -321,8 +321,9 @@ sienaDataCreate<- function(..., nodeSets=NULL, getDocumentation=FALSE)
 				   compositionChange[[v6]] <- dots[[i]]
 				   names(compositionChange)[v6] <- nm[i]
 			   },
-			   stop(paste("invalid object in sienaDataCreate",
-						  class(dots[[i]])), call.=FALSE)
+			   stop(paste("invalid object in sienaDataCreate: argument number",
+					i, "is of class ", class(dots[[i]]),
+					", which is not a valid ... argument."), call.=FALSE)
 			   )
 	if (v1 == 0)
 	{
@@ -338,7 +339,7 @@ sienaDataCreate<- function(..., nodeSets=NULL, getDocumentation=FALSE)
 		if (!(inherits(nodeSets, "sienaNodeSet") || inherits(nodeSets[[1]], "sienaNodeSet")))
 		{
 			stop("nodeSets should be a sienaNodeSet object or a list of such objects")
-		}		
+		}
 	}
 	nodeSetNames <- sapply(nodeSets,function(x) attr(x,"nodeSetName"))
 	names(nodeSets) <- nodeSetNames
@@ -588,10 +589,10 @@ sienaDataCreate<- function(..., nodeSets=NULL, getDocumentation=FALSE)
 		attr(compositionChange[[i]], "activeStart") <- activeStart
 		attr(compositionChange[[i]], "action") <- action
 	}
-	## dependent variables. First we sort the list so discrete and then continuous 
+	## dependent variables. First we sort the list so discrete and then continuous
 	## behavior are at the end
 	types <- sapply(depvars, function(x)attr(x, "type"))
-	depvars <- depvars[c(which(!(types %in% c('behavior', 'continuous'))), 
+	depvars <- depvars[c(which(!(types %in% c('behavior', 'continuous'))),
 						which(types == 'behavior'), which(types == "continuous"))]
 
 	for (i in 1:v1) ## dependent variables
@@ -672,7 +673,7 @@ sienaDataCreate<- function(..., nodeSets=NULL, getDocumentation=FALSE)
 						   )
 			}
 			else # type == 'continuous', input the medians here; these will be
-				 #						 used for missing data imputation 
+				 #						 used for missing data imputation
 			{
 				modes <- apply(depvars[[i]][, 1, ], 2, median, na.rm=TRUE)
 			}
@@ -2391,7 +2392,7 @@ covarDist2 <- function(z)
 	for (i in seq(along=z$cCovars))
 	{
 		nodeSet <- attr(z$cCovars[[i]], "nodeSet")
-		use <- (netTypes != "behavior" & netActorSet == nodeSet)
+		use <- (!(netTypes %in% c("behavior", "continuous")) & (netActorSet == nodeSet))
 		simMeans <- namedVector(NA, netNames[use])
 		for (j in which(use))
 		{
@@ -2404,7 +2405,7 @@ covarDist2 <- function(z)
 	for (i in seq(along=z$vCovars))
 	{
 		nodeSet <- attr(z$vCovars[[i]], "nodeSet")
-		use <- (netTypes != "behavior" & netActorSet == nodeSet)
+		use <- (!(netTypes %in% c("behavior", "continuous")) & (netActorSet == nodeSet))
 		simMeans <- namedVector(NA, netNames[use])
 		for (j in which(use))
 		{
@@ -2422,7 +2423,7 @@ covarDist2 <- function(z)
 			## take off the mean NB no structurals yet!
 			beh <- beh - mean(beh, na.rm=TRUE)
 			nodeSet <- netActorSet[i]
-			use <- (!(netTypes %in% c("behavior", "continuous")) 
+			use <- (!(netTypes %in% c("behavior", "continuous"))
 			        & netActorSet == nodeSet)
 			simMeans <- namedVector(NA, netNames[use])
 			for (j in which(use))
