@@ -34,6 +34,7 @@
 #include "BehaviorInteractionEffect.h"
 #include "BetweennessEffect.h"
 #include "BothDegreesEffect.h"
+#include "ConstantEffect.h"
 #include "CovariateAlterEffect.h"
 #include "CovariateContrastEffect.h"
 #include "CovariateDiffEffect.h"
@@ -44,6 +45,7 @@
 #include "CovariateEgoDiffEffect.h"
 #include "CovariateIndirectTiesEffect.h"
 #include "CovariateSimilarityEffect.h"
+#include "CovariateTransitiveTripletsEffect.h"
 #include "DenseTriadsBehaviorEffect.h"
 #include "DenseTriadsEffect.h"
 #include "DenseTriadsSimilarityEffect.h"
@@ -107,6 +109,7 @@
 #include "HomCovariateTransitiveTripletsEffect.h"
 #include "SameCovariateTransitiveReciprocatedTripletsEffect.h"
 #include "SimilarityEffect.h"
+#include "SimilarityIndegreeEffect.h"
 #include "SimilarityWEffect.h"
 #include "SimilarityTransitiveTripletsEffect.h"
 #include "ThreeCyclesEffect.h"
@@ -123,4 +126,7 @@
 #include "WWXClosureEffect.h"
 #include "WXXClosureEffect.h"
 #include "XWXClosureEffect.h"
+#include "AgreementTransitivityGMMEffect.h"
+#include "RealTransitivityGMMEffect.h"
+#include "ReciprocityGMMEffect.h"
 #endif /*ALLEFFECTS_H_*/
