@@ -39,10 +39,10 @@
 #include "model/effects/generic/OutJaccardFunction.h"
 #include "model/effects/generic/ReciprocatedTwoPathFunction.h"
 #include "model/effects/generic/TwoPathFunction.h"
+#include "model/effects/generic/TwoStepFunction.h"
 #include "model/effects/generic/ReverseTwoPathFunction.h"
-#include "model/effects/generic/MixedTwoPathFunction.h"
-#include "model/effects/generic/MixedInStarFunction.h"
-#include "model/effects/generic/MixedOutStarFunction.h"
+#include "model/effects/generic/MixedTwoStepFunction.h"
+#include "model/effects/generic/WeightedMixedTwoPathFunction.h"
 #include "model/effects/generic/ConditionalFunction.h"
 #include "model/effects/generic/EqualCovariatePredicate.h"
 #include "model/effects/generic/MissingCovariatePredicate.h"
@@ -73,6 +73,58 @@ using namespace std;
 
 namespace siena
 {
+/**
+ * GMM group information. Maps effect short names to the one unique gmm group
+ * (usually the basic effect). In addition there are two special groups. The
+ * empty string ("") meaning a match by position (diagonal matrix) and the
+ * star ("*") meaning matching all.
+ */
+const std::string EffectFactory::gmmGroup(const EffectInfo* pEffectInfo) {
+	// map basic rates to the empty group, that is match by position
+	if (pEffectInfo->effectName() == "BasicRate") {
+	//	LOGF(Priority::INFO, "'%s' in gmm group '%s'",
+	//			pEffectInfo->effectName().c_str(), "");
+		return "";
+	}
+	map<const string, const string>::const_iterator it =
+		EffectFactory::GMM_GROUPS.find(pEffectInfo->effectName());
+	// if group is not specified, map to base name
+	if (it == EffectFactory::GMM_GROUPS.end()) {
+	//	LOGF(Priority::INFO, "'%s' in gmm group '%s'",
+	//			pEffectInfo->effectName().c_str(), pEffectInfo->effectName().c_str());
+		return pEffectInfo->effectName();
+	}
+	// otherwise return the group
+	//LOGF(Priority::INFO, "'%s' in gmm group '%s'",
+	//		pEffectInfo->effectName().c_str(), it->second.c_str());
+	return it->second;
+}
+const map<const string, const string> EffectFactory::GMM_GROUPS = init_groups();
+map<const string, const string> EffectFactory::init_groups() {
+	map<const string, const string> map;
+	map.insert(make_pair("recip", "recip"));
+	map.insert(make_pair("newrecip", "recip"));
+	map.insert(make_pair("realrecip", "recip"));
+	map.insert(make_pair("persistrecip", "recip"));
+	//
+	map.insert(make_pair("transTrip", "transTrip"));
+	//
+	map.insert(make_pair("egoX", "egoX"));
+	map.insert(make_pair("egoX_gmm", "egoX"));
+	map.insert(make_pair("outdeg", "egoX"));
+	//
+	map.insert(make_pair("simX", "simX"));
+	map.insert(make_pair("simX_gmm", "simX"));
+	map.insert(make_pair("totSim", "simX"));
+	map.insert(make_pair("totSim_gmm", "simX"));
+	map.insert(make_pair("avSim_gmm", "avSim"));
+	map.insert(make_pair("avAlt_gmm", "avAlt"));
+	map.insert(make_pair("totAlt_gmm", "totAlt"));
+	map.insert(make_pair("maxAlt_gmm", "maxAlt"));
+	map.insert(make_pair("minAlt_gmm", "minAlt"));
+	return map;
+}
+
 /**
  * Constructor.
  * @param[in] pData the data this factory will create effects for
@@ -91,12 +143,12 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	Effect * pEffect = 0;
 	string effectName = pEffectInfo->effectName();
 
-	// Defined so we can later on differentiate between effects for 
+	// Defined so we can later on differentiate between effects for
 	// continuous and discrete dependent behavior variables
 	string variableName = pEffectInfo->variableName();
-	ContinuousLongitudinalData * pContinuousData = 
+	ContinuousLongitudinalData * pContinuousData =
         dynamic_cast<ContinuousLongitudinalData *>(this->lpData->pContinuousData(variableName));
-	
+
 	// Handle the user-defined interaction effects first.
 
 	if (pEffectInfo->pEffectInfo1())
@@ -156,6 +208,21 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new ReciprocityEffect(pEffectInfo);
 	}
+	else if (effectName == "newrecip")
+	{
+		pEffect = new ReciprocityGMMEffect(pEffectInfo,
+				ReciprocityGMMEffect::NEW);
+	}
+	else if (effectName == "realrecip")
+	{
+		pEffect = new ReciprocityGMMEffect(pEffectInfo,
+				ReciprocityGMMEffect::REAL);
+	}
+	else if (effectName == "persistrecip")
+	{
+		pEffect = new ReciprocityGMMEffect(pEffectInfo,
+				ReciprocityGMMEffect::PERSISTENT);
+	}
 	else if (effectName == "transTrip1")
 	{
 		pEffect = new TransitiveTripletsEffect(pEffectInfo,true,false);
@@ -168,6 +235,14 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new TransitiveTripletsEffect(pEffectInfo,true,true);
 	}
+	else if (effectName == "agreetrans")
+	{
+		pEffect = new AgreementTransitivityEffect(pEffectInfo);
+	}
+	else if (effectName == "realtrans")
+	{
+		pEffect = new RealTransitivityEffect(pEffectInfo);
+	}
 	else if (effectName == "transTriads")
 	{
 		pEffect = new TransitiveTriadsEffect(pEffectInfo);
@@ -384,7 +459,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new CovariateEgoSquaredEffect(pEffectInfo);
 	}
-	else if (effectName == "egoX_sim")
+	else if (effectName == "egoX_gmm")
 	{
 		pEffect = new CovariateEgoEffect(pEffectInfo, false, false, true);
 	}
@@ -436,7 +511,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new CovariateSimilarityEffect(pEffectInfo, false);
 	}
-	else if (effectName == "simX_sim")
+	else if (effectName == "simX_gmm")
 	{
 		pEffect = new CovariateSimilarityEffect(pEffectInfo, false, true);
 	}
@@ -444,7 +519,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new CovariateSimilarityEffect(pEffectInfo, true);
 	}
-	else if (effectName == "simRecipX_sim")
+	else if (effectName == "simRecipX_gmm")
 	{
 		pEffect = new CovariateSimilarityEffect(pEffectInfo, true, true);
 	}
@@ -480,6 +555,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new SameCovariateTransitiveReciprocatedTripletsEffect(pEffectInfo, false);
 	}
+	else if (effectName == "homXTransRecTrip")
+	{
+		pEffect = new HomCovariateTransitiveTripletsEffect(pEffectInfo, true);
+	}
 	else if (effectName == "inPopX")
 	{
 		string networkName = pEffectInfo->variableName();
@@ -566,6 +645,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new SameCovariateActivityEffect(pEffectInfo, false, true);
 	}
+	else if (effectName == "transTripX")
+	{
+		pEffect = new CovariateTransitiveTripletsEffect(pEffectInfo);
+	}
 	else if (effectName == "homXTransTrip")
 	{
 		pEffect = new HomCovariateTransitiveTripletsEffect(pEffectInfo, false);
@@ -892,51 +975,140 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	else if (effectName == "from")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new InStarFunction(pEffectInfo->interactionName1()));
+			new InStarFunction(pEffectInfo->interactionName1(),
+							(pEffectInfo->internalEffectParameter() >= 2)));
 	}
 	else if (effectName == "fromMutual")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new ReciprocatedTwoPathFunction(pEffectInfo->interactionName1()));
+			new ReciprocatedTwoPathFunction(pEffectInfo->interactionName1(),
+							(pEffectInfo->internalEffectParameter() >= 2)));
 	}
 	else if (effectName == "to")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new MixedTwoPathFunction(pEffectInfo->interactionName1(),
-				pEffectInfo->variableName()));
+				new MixedTwoStepFunction(
+						pEffectInfo->interactionName1(),
+						pEffectInfo->variableName(),
+						FORWARD, FORWARD, (pEffectInfo->internalEffectParameter()>=2)));
 	}
-	else if (effectName == "mixedInWX")
+	else if (effectName == "toBack") // formerly mixedInWX
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new MixedOutStarFunction(pEffectInfo->interactionName1(),
-				pEffectInfo->variableName()));
-	}
-	else if (effectName == "mixedInXW")
+				new MixedTwoStepFunction(
+						pEffectInfo->interactionName1(),
+						pEffectInfo->variableName(),
+						BACKWARD, FORWARD, (pEffectInfo->internalEffectParameter()>=2)));
+		}
+	else if (effectName == "toRecip")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new MixedOutStarFunction(pEffectInfo->variableName(),
-				pEffectInfo->interactionName1()));
-	}
+				new MixedTwoStepFunction(
+						pEffectInfo->interactionName1(),
+						pEffectInfo->variableName(),
+						RECIPROCAL, FORWARD, (pEffectInfo->internalEffectParameter()>=2)));
+		}
 	else if (effectName == "cl.XWX")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new SumFunction(
-			new MixedTwoPathFunction(pEffectInfo->variableName(),
-					pEffectInfo->interactionName1()),
-			new MixedInStarFunction(pEffectInfo->variableName(),
-					pEffectInfo->interactionName1())));
+			new MixedTwoStepFunction(
+						pEffectInfo->variableName(),
+						pEffectInfo->interactionName1(),
+						FORWARD, FORWARD, false),
+			new MixedTwoStepFunction(
+						pEffectInfo->variableName(),
+						pEffectInfo->interactionName1(),
+						FORWARD, BACKWARD, false)));
 	}
 	else if (effectName == "cl.XWX1")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new MixedTwoPathFunction(pEffectInfo->variableName(),
-					pEffectInfo->interactionName1()));
+					new MixedTwoStepFunction(
+						pEffectInfo->variableName(),
+						pEffectInfo->interactionName1(),
+						FORWARD, FORWARD, false));
 	}
 	else if (effectName == "cl.XWX2")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new MixedInStarFunction(pEffectInfo->variableName(),
-					pEffectInfo->interactionName1()));
+			new  MixedTwoStepFunction(
+						pEffectInfo->variableName(),
+						pEffectInfo->interactionName1(),
+						FORWARD, BACKWARD, false));
+	}
+	else if (effectName == "mixedInXW")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+				new MixedTwoStepFunction(
+						pEffectInfo->variableName(),
+						pEffectInfo->interactionName1(),
+						BACKWARD, FORWARD, (pEffectInfo->internalEffectParameter()>=2)));
+	}
+	/*
+	 * Mixed two step effects with flexible iterators (added by Christoph)
+	 */
+	else if (effectName == "transTrip.FR")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new TwoStepFunction(pEffectInfo->variableName(),
+					FORWARD, RECIPROCAL));
+	}
+	else if (effectName == "transTrip.EE")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new MixedTwoStepFunction(pEffectInfo->variableName(), // not mixed, TwoStepFunction equivalent not implemented
+					pEffectInfo->variableName(),
+					EITHER, EITHER, false));
+	}
+	else if (effectName == "transTrip.FE")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new MixedTwoStepFunction(pEffectInfo->variableName(), // not mixed, TwoStepFunction equivalent not implemented
+					pEffectInfo->variableName(),
+					FORWARD, EITHER, false));
+	}
+	else if (effectName == "WWX.EE")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new MixedTwoStepFunction(pEffectInfo->interactionName1(), // not mixed
+					pEffectInfo->interactionName1(),
+					EITHER, EITHER, false));
+	}
+	else if (effectName == "WXX.FE")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new MixedTwoStepFunction(pEffectInfo->interactionName1(),
+					pEffectInfo->variableName(),
+					FORWARD, EITHER, false));
+	}
+	else if (effectName == "XWX.ER")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new MixedTwoStepFunction(pEffectInfo->variableName(),
+					pEffectInfo->interactionName1(),
+					EITHER, RECIPROCAL, false));
+	}
+	else if (effectName == "WWX.FR")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new MixedTwoStepFunction(pEffectInfo->interactionName1(),  // not mixed
+					pEffectInfo->interactionName1(),
+					FORWARD, RECIPROCAL, false));
+	}
+	else if (effectName == "WXX.ER")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new MixedTwoStepFunction(pEffectInfo->interactionName1(),
+					pEffectInfo->variableName(),
+					EITHER, RECIPROCAL, false));
+	}
+	else if (effectName == "XWX.FE")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new MixedTwoStepFunction(pEffectInfo->variableName(),
+					pEffectInfo->interactionName1(),
+					FORWARD, EITHER, false));
 	}
 	else if (effectName == "outOutActIntn")
 	{
@@ -948,121 +1120,19 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	else if (effectName == "sharedTo")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new MixedThreeCyclesFunction(pEffectInfo->interactionName1(),
-				pEffectInfo->variableName(),
-				pEffectInfo->internalEffectParameter()));
+						new MixedThreeCyclesFunction(pEffectInfo->variableName(),
+							pEffectInfo->interactionName1(),
+							pEffectInfo->internalEffectParameter()));
 	}
-	else if (effectName == "inPopIntnX")
+	else if (effectName == "toU")
 	{
-		string networkName = pEffectInfo->interactionName1();
-		string covariateName = pEffectInfo->interactionName2();
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new CovariateDegreeFunction(networkName, covariateName,
-					false, true, false, (pEffectInfo->internalEffectParameter()>=2)),
-			new CovariateDegreeFunction(networkName, covariateName,
-					true, true, false, (pEffectInfo->internalEffectParameter()>=2)));
-	}
-	else if (effectName == "inActIntnX")
-	{
-		string networkName = pEffectInfo->interactionName1();
-		string covariateName = pEffectInfo->interactionName2();
-		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new CovariateDegreeFunction(networkName, covariateName,
-					false, true, true, (pEffectInfo->internalEffectParameter()>=2)),
-			new CovariateDegreeFunction(networkName, covariateName,
-					true, true, true, (pEffectInfo->internalEffectParameter()>=2)));
-	}
-	else if (effectName == "outPopIntnX")
-	{
-		string networkName = pEffectInfo->interactionName1();
-		string covariateName = pEffectInfo->interactionName2();
-		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new CovariateDegreeFunction(networkName, covariateName,
-					false, false, false, (pEffectInfo->internalEffectParameter()>=2)),
-			new CovariateDegreeFunction(networkName, covariateName,
-					true, false, false, (pEffectInfo->internalEffectParameter()>=2)));
-	}
-	else if (effectName == "outActIntnX")
-	{
-		string networkName = pEffectInfo->interactionName1();
-		string covariateName = pEffectInfo->interactionName2();
-		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new CovariateDegreeFunction(networkName, covariateName,
-					false, false, true, (pEffectInfo->internalEffectParameter()>=2)),
-			new CovariateDegreeFunction(networkName, covariateName,
-					true, false, true, (pEffectInfo->internalEffectParameter()>=2)));
-	}
-	else if (effectName == "sameXInPopIntn")
-	{
-		string networkName = pEffectInfo->interactionName1();
-		string covariateName = pEffectInfo->interactionName2();
-		AlterFunction * pChangeFunction =
-			new SameCovariateInTiesFunction(networkName, covariateName,
-									true, false, false);
-		AlterFunction * pStatisticFunction =
-			new SameCovariateInTiesFunction(networkName, covariateName,
-									true, false, true);
-		if (pEffectInfo->internalEffectParameter() == 2)
-		{
-			pChangeFunction = new IntSqrtFunction(pChangeFunction);
-			pStatisticFunction = new IntSqrtFunction(pStatisticFunction);
-		}
-		pEffect = new GenericNetworkEffect(pEffectInfo,
-			pChangeFunction, pStatisticFunction);
-	}
-	else if (effectName == "sameXInActIntn")
-	{
-		string networkName = pEffectInfo->interactionName1();
-		string covariateName = pEffectInfo->interactionName2();
-		AlterFunction * pChangeFunction =
-			new EgoFunction(new SameCovariateInTiesFunction(networkName, covariateName,
-									true, false, false));
-		AlterFunction * pStatisticFunction =
-			new EgoFunction(new SameCovariateInTiesFunction(networkName, covariateName,
-									true, false, true));
-		if (pEffectInfo->internalEffectParameter() == 2)
-		{
-			pChangeFunction = new IntSqrtFunction(pChangeFunction);
-			pStatisticFunction = new IntSqrtFunction(pStatisticFunction);
-		}
-		pEffect = new GenericNetworkEffect(pEffectInfo,
-			pChangeFunction, pStatisticFunction);
-	}
-	else if (effectName == "sameXOutPopIntn")
-	{
-		string networkName = pEffectInfo->interactionName1();
-		string covariateName = pEffectInfo->interactionName2();
-		AlterFunction * pChangeFunction =
-			new SameCovariateOutTiesFunction(networkName,
-									covariateName, true, false);
-		AlterFunction * pStatisticFunction =
-			new SameCovariateOutTiesFunction(networkName,
-									covariateName, true, true);
-		if (pEffectInfo->internalEffectParameter() == 2)
-		{
-			pChangeFunction = new IntSqrtFunction(pChangeFunction);
-			pStatisticFunction = new IntSqrtFunction(pStatisticFunction);
-		}
-		pEffect = new GenericNetworkEffect(pEffectInfo,
-			pChangeFunction, pStatisticFunction);
-	}
-	else if (effectName == "sameXOutActIntn")
-	{
-		string networkName = pEffectInfo->interactionName1();
-		string covariateName = pEffectInfo->interactionName2();
-		AlterFunction * pChangeFunction =
-			new EgoFunction(new SameCovariateOutTiesFunction(networkName,
-									covariateName, true, false));
-		AlterFunction * pStatisticFunction =
-			new EgoFunction(new SameCovariateOutTiesFunction(networkName,
-									covariateName, true, true));
-		if (pEffectInfo->internalEffectParameter() == 2)
-		{
-			pChangeFunction = new IntSqrtFunction(pChangeFunction);
-			pStatisticFunction = new IntSqrtFunction(pStatisticFunction);
-		}
-		pEffect = new GenericNetworkEffect(pEffectInfo,
-			pChangeFunction, pStatisticFunction);
+			new WeightedMixedTwoPathFunction(pEffectInfo->interactionName1(),
+					pEffectInfo->variableName(),
+					pEffectInfo->interactionName2(), false),
+			new WeightedMixedTwoPathFunction(pEffectInfo->interactionName1(),
+					pEffectInfo->variableName(),
+					pEffectInfo->interactionName2(), true));
 	}
 	else if (effectName == "covNetNet")
 	{
@@ -1070,14 +1140,14 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		string covariateName = pEffectInfo->interactionName2();
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new ConditionalFunction(new EqualCovariatePredicate(covariateName),
-				new InStarFunction(networkName),
+				new InStarFunction(networkName, false),
 				0),
 			new ConditionalFunction(
 				new MissingCovariatePredicate(covariateName),
 				0,
 				new ConditionalFunction(
 					new EqualCovariatePredicate(covariateName),
-					new InStarFunction(networkName),
+					new InStarFunction(networkName, false),
 					0)));
 	}
 	else if (effectName == "homCovNetNet")
@@ -1337,18 +1407,50 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new QuadraticShapeEffect(pEffectInfo);
 	}
+	else if (effectName == "constant")
+	{
+		pEffect = new ConstantEffect(pEffectInfo);
+	}
 	else if ((effectName == "threshold") | (effectName == "threshold2") |
-	         (effectName == "threshold3") |(effectName == "threshold3"))
+	         (effectName == "threshold3") |(effectName == "threshold4"))
 	{
 		pEffect = new ThresholdShapeEffect(pEffectInfo);
 	}
 	else if (effectName == "avSim")
 	{
-		pEffect = new SimilarityEffect(pEffectInfo, true, false, false);
+		pEffect = new SimilarityEffect(pEffectInfo, true, false, false, true, true);
+	}
+	else if (effectName == "avAttHigher")
+	{
+		pEffect = new SimilarityEffect(pEffectInfo, true, false, false, true, false);
+	}
+	else if (effectName == "avAttLower")
+	{
+		pEffect = new SimilarityEffect(pEffectInfo, true, false, false, false, true);
+	}
+	else if (effectName == "avSim_gmm")
+	{
+		pEffect = new SimilarityEffect(pEffectInfo, true, false, false, true, true, true);
 	}
 	else if (effectName == "totSim")
 	{
-		pEffect = new SimilarityEffect(pEffectInfo, false, false, false);
+		pEffect = new SimilarityEffect(pEffectInfo, false, false, false, true, true);
+	}
+	else if (effectName == "totAttHigher")
+	{
+		pEffect = new SimilarityEffect(pEffectInfo, false, false, false, true, false);
+	}
+	else if (effectName == "totAttLower")
+	{
+		pEffect = new SimilarityEffect(pEffectInfo, false, false, false, false, true);
+	}
+	else if (effectName == "avInSim")
+	{
+		pEffect = new SimilarityIndegreeEffect(pEffectInfo, true, false);
+	}
+	else if (effectName == "totInSim")
+	{
+		pEffect = new SimilarityIndegreeEffect(pEffectInfo, false, false);
 	}
 	else if (effectName == "indeg")
 	{
@@ -1359,7 +1461,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		else
 		{
 		pEffect = new IndegreeEffect(pEffectInfo);
-	}
+		}
 	}
 	else if (effectName == "indegSqrt")
 	{
@@ -1377,7 +1479,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		else
 		{
 		pEffect = new OutdegreeEffect(pEffectInfo);
-	}
+		}
 	}
 	else if (effectName == "outdegSqrt")
 	{
@@ -1469,7 +1571,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	else if (effectName == "settingLogCreationActD")
 	{
 		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, true, true);
-	}	
+	}
 	else if (effectName == "avSimRecip")
 	{
 		pEffect = new ReciprocatedSimilarityEffect(pEffectInfo, true, false);
@@ -1480,11 +1582,19 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "avSimPopAlt")
 	{
-		pEffect = new SimilarityEffect(pEffectInfo, true, true, false);
+		pEffect = new SimilarityEffect(pEffectInfo, true, true, false, true, true);
 	}
 	else if (effectName == "totSimPopAlt")
 	{
-		pEffect = new SimilarityEffect(pEffectInfo, false, true, false);
+		pEffect = new SimilarityEffect(pEffectInfo, false, true, false, true, true);
+	}
+	else if (effectName == "avInSimPopAlt")
+	{
+		pEffect = new SimilarityIndegreeEffect(pEffectInfo, true, true);
+	}
+	else if (effectName == "totInSimPopAlt")
+	{
+		pEffect = new SimilarityIndegreeEffect(pEffectInfo, false, true);
 	}
 	else if (effectName == "popAlt")
 	{
@@ -1505,10 +1615,14 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 			pEffect = new AverageAlterContinuousEffect(pEffectInfo);
 		}
 		else
-		{	
+		{
 		pEffect = new AverageAlterEffect(pEffectInfo, true, false);
 	}
 	}
+	else if (effectName == "avAlt_gmm")
+	{
+		pEffect = new AverageAlterEffect(pEffectInfo, true, false, true);
+	}
 	else if (effectName == "avGroup")
 	{
 		pEffect = new AverageGroupEffect(pEffectInfo);
@@ -1517,6 +1631,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new AverageAlterEffect(pEffectInfo, false, false);
 	}
+	else if (effectName == "totAlt_gmm")
+	{
+		pEffect = new AverageAlterEffect(pEffectInfo, false, false, true);
+	}
 	else if (effectName == "avAltPop")
 	{
 		pEffect = new AverageAlterEffect(pEffectInfo, true, true);
@@ -1544,6 +1662,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		pEffect = new MaxAlterEffect(pEffectInfo, false);
 	}
 	}
+	else if (effectName == "maxAlt_gmm")
+	{
+		pEffect = new MaxAlterEffect(pEffectInfo, false, true);
+	}
 	else if (effectName == "minAlt")
 	{
 		if (pContinuousData)
@@ -1555,6 +1677,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		pEffect = new MaxAlterEffect(pEffectInfo, true);
 	}
 	}
+	else if (effectName == "minAlt_gmm")
+	{
+		pEffect = new MaxAlterEffect(pEffectInfo, true, true);
+	}
 	else if (effectName == "avInAlt")
 	{
 		pEffect = new AverageInAlterEffect(pEffectInfo, true);
@@ -1644,11 +1770,11 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 //	else if (effectName == "RRDeg")
 //	{
-//		pEffect = new DoubleRecDegreeBehaviorEffect(pEffectInfo, 2); // crashes
+//		pEffect = new DoubleRecDegreeBehaviorEffect(pEffectInfo, 2); // leads to error
 //	}
 	else if (effectName == "avSimPopEgo")
 	{
-		pEffect = new SimilarityEffect(pEffectInfo, true, false, true);
+		pEffect = new SimilarityEffect(pEffectInfo, true, false, true, true, true);
 	}
 	else if (effectName == "effFrom")
 	{
