@@ -13,6 +13,9 @@
 #include "utils/SqrtTable.h"
 #include "network/Network.h"
 #include "model/variables/NetworkVariable.h"
+#include "data/NetworkLongitudinalData.h"
+#include "model/EffectInfo.h"
+#include "data/Data.h"
 
 namespace siena
 {
@@ -21,13 +24,39 @@ namespace siena
  * Constructor.
  */
 IndegreePopularityEffect::IndegreePopularityEffect(
-	const EffectInfo * pEffectInfo, bool root) : NetworkEffect(pEffectInfo)
+	const EffectInfo * pEffectInfo, bool root, bool centered): 
+										NetworkEffect(pEffectInfo)
 {
 	this->lroot = root;
 	this->lsqrtTable = SqrtTable::instance();
+	this->lcentered = centered;
+	this->lcentering = 0.0;
+	this->lvariableName = pEffectInfo->variableName();
+// centering and root cannot occur simultaneously
 }
 
 
+/**
+ * Initializes this function.
+ * @param[in] pData the observed data
+ * @param[in] pState the current state of the dependent variables
+ * @param[in] period the period of interest
+ * @param[in] pCache the cache object to be used to speed up calculations
+ */
+void IndegreePopularityEffect::initialize(const Data * pData,
+	State * pState,
+	int period,
+	Cache * pCache)
+{
+	NetworkEffect::initialize(pData, pState, period, pCache);
+	if (this->lcentered)
+	{
+		NetworkLongitudinalData * pNetworkData =
+				pData->pNetworkData(this->lvariableName);
+		this->lcentering = pNetworkData->averageInDegree();
+	}
+}
+
 /**
  * Calculates the contribution of a tie flip to the given actor.
  */
@@ -41,7 +70,7 @@ double IndegreePopularityEffect::calculateContribution(int alter) const
 		degree++;
 	}
 
-	double change = degree;
+	double change = degree - this->lcentering;
 
 	if (this->lroot)
 	{
@@ -69,7 +98,7 @@ double IndegreePopularityEffect::tieStatistic(int alter)
 	}
 	else
 	{
-		statistic = degree;
+		statistic = degree - this->lcentering;
 	}
 
 	return statistic;
