@@ -22,6 +22,7 @@
 #include "network/Network.h"
 #include "network/OneModeNetwork.h"
 #include "network/IncidentTieIterator.h"
+#include "network/iterators/UnionTieIterator.h"
 #include "data/NetworkLongitudinalData.h"
 #include "data/ConstantDyadicCovariate.h"
 #include "data/ChangingDyadicCovariate.h"
@@ -36,6 +37,15 @@
 #include "model/ml/NetworkChange.h"
 #include "model/filters/PermittedChangeFilter.h"
 #include "model/ml/Chain.h"
+#include "model/settings/Setting.h"
+
+#include <algorithm>
+#include <vector>
+#include <cmath>
+
+#include <Rinternals.h>
+#include <R_ext/Print.h>
+#include <R_ext/Arith.h>
 
 using namespace std;
 
@@ -86,7 +96,9 @@ NetworkVariable::NetworkVariable(NetworkLongitudinalData * pData,
 		this->lcreationEffectContribution = new double * [numberOfAlters];
 		this->lprobabilities = new double[numberOfAlters];
 	}
-
+	for (int i = 0; i < numberSettings(); i++) {
+		lsettings[i]->initSetting(lpNetwork);
+	}
 	this->lsymmetricEvaluationEffectContribution = new double * [2];
 	this->lsymmetricEndowmentEffectContribution = new double * [2];
 	this->lsymmetricCreationEffectContribution = new double * [2];
@@ -120,7 +132,7 @@ NetworkVariable::NetworkVariable(NetworkLongitudinalData * pData,
 		pSimulation->pCache()->pNetworkCache(this->lpNetwork);
 
 	this->lalter = 0;
-	this->lsetting = new vector<int>;
+
 	this->lnetworkModelType = NetworkModelType(pData->modelType());
 
 }
@@ -131,12 +143,14 @@ NetworkVariable::NetworkVariable(NetworkLongitudinalData * pData,
  */
 NetworkVariable::~NetworkVariable()
 {
+	for (int i = 0; i < numberSettings(); i++) {
+		lsettings[i]->terminateSetting(lpNetwork);
+	}
 	delete this->lpNetwork;
 
 	delete[] this->lactiveStructuralTieCount;
 	delete[] this->lpermitted;
 	delete[] this->lprobabilities;
-	delete this->lsetting;
 
 	// Delete arrays of contributions
 	int numberOfAlters;
@@ -530,6 +544,7 @@ bool NetworkVariable::canMakeChange(int actor) const
  * Simulates a change of the network according to the choice of the given
  * actor. First, the actor chooses the alter based on the evaluation and
  * endowment functions, and then the tie to the selected alter is flipped.
+ * Used for MoM.
  */
 void NetworkVariable::makeChange(int actor)
 {
@@ -570,25 +585,23 @@ void NetworkVariable::makeChange(int actor)
 		{
 			m = this->m() + 1;
 		}
-		if (this->stepType() > 0)
+		if (this->stepType() != -1)
 		{
-			m = this->lsetting->size();
-		}
-
-		alter = nextIntWithProbabilities(m,	this->lprobabilities);
-		if (this->stepType() > 0)
-		{
-			alter = (*this->lsetting)[alter];
-		}
-
-		if (this->stepType() > 1)
-		{
-			if (this->lpNetworkCache->outTieExists(alter))
-			{
-				this->successfulChange(false);
+			if (!lsettings[stepType()]->validate(lpNetwork)) {
+				successfulChange(false);
+				lsettings[stepType()]->terminateSetting(ego());
 				return;
 			}
 		}
+
+		alter = nextIntWithProbabilities(m,	this->lprobabilities);
+
+//		if (this->stepType() > 1) {
+//			if (this->lpNetworkCache->outTieExists(alter)) {
+//				this->successfulChange(false);
+//				return;
+//			}
+//		}
 		// Siena 3 checks in the diagonal case, so I do too temporarily.
 		//if (alter != actor && !this->lpNetworkCache->outTieExists(alter) &&
 		//	this->pSimulation()->pModel()->modelType() == AAGREE)
@@ -710,6 +723,9 @@ void NetworkVariable::makeChange(int actor)
 			}
 		}
 	}
+	if (stepType() != -1) {
+		lsettings[stepType()]->terminateSetting(ego());
+	}
 }
 
 
@@ -751,22 +767,32 @@ void NetworkVariable::calculatePermissibleChanges()
 {
 	NetworkLongitudinalData * pData = (NetworkLongitudinalData *) this->pData();
 
-	// Test each alter if a tie flip to that alter is permitted according
-	// to upOnly/downOnly flags and the max degree.
 	int m = this->m();
-	
-	if (this->stepType() > 0)
+	for (int i = 0; i < m; ++i)
 	{
-		m = this->lsetting->size();
+		this->lpermitted[i] = false;
+	}
+	
+	Setting* curSetting = 0;
+	ITieIterator* iter = 0;
+	if (this->stepType() != -1)
+	{
+		curSetting = lsettings[stepType()];
+		iter = curSetting->getSteps();
+		m = curSetting->getSize();
 	}
-// Rprintf("MaxDegree %d \n", pData->maxDegree());
 
+  // Test each alter if a tie flip to that alter is permitted according to
+  // upOnly/downOnly flags and the max degree.
 	for (int ii = 0; ii < m; ii++)
 	{
 		int i = ii;
-		if (this->stepType() > 0)
-		{
-			i = (*this->lsetting)[ii];
+		if (this->stepType() > -1) {
+			if (!iter->valid()) {
+				error( "size of iterator != size setting");
+			}
+			i = iter->actor();
+			iter->next();
 		}
 
 		if (this->lpNetworkCache->outTieExists(i))
@@ -787,6 +813,9 @@ void NetworkVariable::calculatePermissibleChanges()
 			this->lpermitted[i] = true;
 		}
 	}
+	if (iter != 0) {
+		delete iter;
+	}
 
 	// Prohibit the change of structural ties
 
@@ -807,15 +836,12 @@ void NetworkVariable::calculatePermissibleChanges()
 		pFilter->filterPermittedChanges(this->lego, this->lpermitted);
 		//Rprintf(" filtered %d %d\n ", i, this->lpermitted[10]);
 	}
-//	if (this->id() > 0)
-//	for (int i = 0; i < m; i++)
-//	 {
-//		 	 Rprintf("permitted %d %d %d\n", i, this->lpermitted[i], m);
-//	 }
 
-	if (!this->oneModeNetwork())
+	// ensure that no change is a permitted change
+	if (this->oneModeNetwork())
 	{
-		// It is okay to not make any change at all
+		this->lpermitted[lego] = true;
+	} else {
 		this->lpermitted[m] = true;
 	}
 
@@ -846,17 +872,25 @@ void NetworkVariable::calculateTieFlipContributions()
 
 	int m = this->m();
 	int alter = 0;
-	if (this->stepType() > 0)
+	Setting* curSetting = 0;
+	ITieIterator* permIter = 0;
+	if (this->stepType() != -1)
 	{
-		m = this->lsetting->size();
+		curSetting = lsettings[stepType()];
+		permIter = curSetting->getPermittedSteps();
+		m = curSetting->getPermittedSize();
 	}
 	for (int alteri = 0; alteri < m; alteri++)
 	{
 		alter = alteri;
 
-		if (this->stepType() > 0)
+		if (this->stepType() != -1)
 		{
-			alter = (*this->lsetting)[alteri];
+			if (!permIter->valid()) {
+				error("permitted iter length != settings permitted size");
+			}
+			alter = permIter->actor();
+			permIter->next();
 		}
 
 		// alter = ego for one-mode networks means no change.
@@ -866,7 +900,7 @@ void NetworkVariable::calculateTieFlipContributions()
 
 		if (this->lpermitted[alter] && (twoModeNetwork || alter != this->lego))
 		// The second condition seems superfluous,
-		// as (alter = this->lego) is dealt with later.
+		// as (alter == this->lego) is dealt with later.
 		// TODO: check if this can safely be dropped.
 		{
 			for (int i = 0; i < evaluationEffectCount; i++)
@@ -898,7 +932,7 @@ void NetworkVariable::calculateTieFlipContributions()
 
 		// The endowment effects have non-zero contributions on tie
 		// withdrawals only
-
+		// TODO: Isn't there && (twoModeNetwork || alter != this->lego) missing?
 		if (this->lpNetworkCache->outTieExists(alter) &&
 			this->lpermitted[alter])
 		{
@@ -957,6 +991,9 @@ void NetworkVariable::calculateTieFlipContributions()
 			}
 		}
 	}
+	if (permIter != 0) {
+		delete permIter;
+	}
 
 	// need to initialise the no-effect option of alter = this->m() for
 	// twomode networks
@@ -1000,24 +1037,135 @@ void NetworkVariable::calculateTieFlipContributions()
 
 
 /**
- * Calculates the probability of each actor of being chosen for the next
- * tie flip.
+ * If Settings model, chooses the setting; 
+ * calculates the probability of each actor
+ * for being chosen as alter for the next tie flip.
  */
 void NetworkVariable::calculateTieFlipProbabilities()
 {
+	NetworkLongitudinalData * pData = (NetworkLongitudinalData *) this->pData();
+	// If a settings model, decide what to do. Pre-store probabilities
+	this->getStepType();
+//	if (this->stepType() > 1)
+//	{
+//		// clear settings vector
+//		this->lsetting->clear();
+//		// find the covariate and make a vector of potential alters
+//		NetworkLongitudinalData * pNetworkData =
+//			dynamic_cast<NetworkLongitudinalData *>(this->pData());
+//		string settingName = pNetworkData->rSettingNames()[this->stepType()];
+//		ConstantDyadicCovariate * pConstantCovariate =
+//			this->pSimulation()->pData()->pConstantDyadicCovariate(settingName);
+//	   ChangingDyadicCovariate * pChangingCovariate =
+//			this->pSimulation()->pData()->pChangingDyadicCovariate(settingName);
+//		map<int, double> row;
+//		if (pConstantCovariate) // TODO: What is this?
+//		{
+//			row = pConstantCovariate->rRowValues(this->lego);
+//		}
+//		else if (pChangingCovariate)
+//		{
+//			row = pChangingCovariate->rRowValues(this->lego, this->period());
+//		}
+//		else
+//		{
+//			error("setting not found");
+//		}
+//		bool needEgo = true;
+//		if (row.size() == 0)
+//		{
+//			this->lsetting->push_back(this->lego);
+//			needEgo = false;
+//		}
+//
+//		for (map<int, double>::iterator iter=row.begin();
+//			 iter != row.end(); iter++ )
+//		{
+//			if (iter->first > this->lego && needEgo)
+//			{
+//				this->lsetting->push_back(this->lego);
+//				needEgo = false;
+//			}
+//			this->lsetting->push_back(iter->first);
+//		}
+//		if (needEgo)
+//		{
+//			this->lsetting->push_back(this->lego);
+//		}
+//	}
+//	// TODO: correct this->lsetting for primary setting
+//	if (this->stepType() == 1)
+//	{
+//	{
+//		delete this->lsetting;
+//		this->lsetting = primarySetting(this->pNetwork(), this->lego);
+//	}
+	if (stepType() > -1)
+	{
+		initializeSetting(); 
+		this->lpNetworkCache->stepTypeSet(stepType());
+	}
 	this->preprocessEgo(this->lego);
 	this->calculatePermissibleChanges();
+//	int m = this->m();
+//
+//	if (!this->oneModeNetwork())
+//	{
+//		m = this->m() + 1;
+//	}
+	// TODO: check correctness
+	if (this->stepType() != -1)
+	{
+		lsettings[stepType()]->initPermittedSteps(lpermitted);
+		// if there is only one permissable change (ego) return
+		if (!lsettings[stepType()]->validate(lpNetwork))
+		{
+			return;
+		}
+	}
+//		//  check we can find an ego in the setting
+//		int numberPermitted = 0;
+//		for (int i = 0; i < m; i++)
+//		{
+//			int ii = i;
+//			if (this->stepType() > 0)
+//			{
+//				ii = (*this->lsetting)[i];
+//			}
+//			if (this->lpermitted[ii])
+//			{
+//				numberPermitted++;
+//			}
+//		}
+//		int fastAlter = this->lego;
+//
+//		if (numberPermitted > 1)
+//		{
+//			while(fastAlter == this->lego && this->lpermitted[fastAlter])
+//			{
+//				fastAlter = nextInt(m);  // random number
+//				if (this->stepType()  > 1)
+//				{
+//					fastAlter = (*this->lsetting)[fastAlter];
+//				}
+//			}
+//		}
+//		this->lsetting->clear();
+//		this->lsetting->push_back(min(this->lego, fastAlter));
+//		this->lsetting->push_back(max(this->lego, fastAlter));
+//	}
+
 	this->calculateTieFlipContributions();
 
 	int evaluationEffectCount = this->pEvaluationFunction()->rEffects().size();
 	int endowmentEffectCount = this->pEndowmentFunction()->rEffects().size();
 	int creationEffectCount = this->pCreationFunction()->rEffects().size();
-	if (this->pSimulation()->pModel()->needChangeContributions())
 
-	{
-		this->lpChangeContribution = new map<const EffectInfo *, vector<double> >[evaluationEffectCount+endowmentEffectCount+creationEffectCount];
-		for (int i = 0; i < evaluationEffectCount; i++)
-		{
+	if (this->pSimulation()->pModel()->needChangeContributions()) {
+		this->lpChangeContribution =
+				new map<const EffectInfo *, vector<double> >();
+// used to be  >[evaluationEffectCount+endowmentEffectCount+creationEffectCount];
+		for (int i = 0; i < evaluationEffectCount; i++) {
 			vector<double> vec(this->m(),0);
 			this->lpChangeContribution->insert(make_pair(
 						this->pEvaluationFunction()->rEffects()[i]->pEffectInfo(), vec));
@@ -1041,6 +1189,29 @@ void NetworkVariable::calculateTieFlipProbabilities()
 					// because there always is the no-change option
 	int m = this->m(); // not this->m()+1 for two-mode network;
 					// this is handled separately below
+//	double primaryOffset = 0;
+
+	Setting* curSetting = 0;
+	ITieIterator* permIter = 0;
+	if (this->stepType() != -1)
+	{
+		curSetting = lsettings[stepType()];
+		permIter = curSetting->getPermittedSteps();
+		m = curSetting->getPermittedSize();
+		if (this->stepType() == 1)
+		{
+			int egoOutDegree = 0;
+			egoOutDegree = this->lpNetwork->outDegree(this->lego);
+			if (egoOutDegree > m)
+			{
+					error("outdegree > primary setting size");
+			}
+//			else if (egoOutDegree < m)
+//			{
+//				primaryOffset = -std::log(m - egoOutDegree);
+//			}
+		}
+	}
 
 	// calculate all contributions then subtract the largest to remove overflow
 	int alter = 0;
@@ -1048,6 +1219,15 @@ void NetworkVariable::calculateTieFlipProbabilities()
 	for (int alteri = 0; alteri < m; alteri++)
 	{
 		alter = alteri;
+		if (curSetting)
+		{
+			if (!permIter->valid())
+		{
+				error( "permIter size differs from setting size");
+		}
+			alter = permIter->actor();
+			permIter->next();
+		}
 		if (this->lpermitted[alter])
 		{
 			// Calculate the total contribution of all effects
@@ -1093,23 +1273,45 @@ void NetworkVariable::calculateTieFlipProbabilities()
 							this->lcreationEffectContribution[alter][i];
 					}
 				}
+//				for settings model:
+				if ((this->stepType() == 0) || (this->stepType() >= 2))
+				{
+					contribution += pData->universalOffset();
+				}
+//				else if (this->stepType() == 1)
+//				{
+//					contribution += primaryOffset;
+//				}
 			}
 
 			// The selection probability is the exponential of the total
 			// contribution.
-			this->lprobabilities[alteri] = contribution;
-			//	Rprintf("p1 %d %f \n", alteri, contribution);
+			this->lprobabilities[alter] = contribution;
+			//	Rprintf("p1 %d %f \n", alter, contribution);
 			sumPermitted++;
 		}
 		else
 		{
-			this->lprobabilities[alteri] = R_NegInf;
+			this->lprobabilities[alter] = R_NegInf;
 		}
-		maxValue = max(maxValue, this->lprobabilities[alteri]);
+		maxValue = max(maxValue, this->lprobabilities[alter]);
+		}
+
+	if (permIter != 0) {
+		permIter->reset();
+	}
+
+	for (int alteri = 0; alteri < m; alteri++) {
+		alter = alteri;
+
+		if (this->stepType() != -1) {
+			if (!permIter->valid()) {
+				error( "permitted iter length != settings permitted size");
+		}
+			alter = permIter->actor();
+			permIter->next();
 	}
 	
-	for (int alter = 0; alter < m; alter++)
-	{
 		if (this->lpermitted[alter])
 		{
 			this->lprobabilities[alter] -= 	maxValue;
@@ -1122,6 +1324,8 @@ void NetworkVariable::calculateTieFlipProbabilities()
 		}
 	}
 
+	// reset m in case of settings
+	m = this->m();
 	if (!this->oneModeNetwork())
 	{
 		if (sumPermitted >= 2)
@@ -1138,19 +1342,52 @@ void NetworkVariable::calculateTieFlipProbabilities()
 		     // this in mind if further statements are added to this procedure.
 	}
 
+	// delete iter
+	if (permIter != 0) {
+		permIter->reset();
+	}
+
 	// Normalize
-	if (total > 0)
-	{
+	if (total > 0) {
+		// this loop requires that permIter processes its entries in ascending order (which it does)
 		for (int alter = 0; alter < m; alter++)
 		{
+			if (permIter != 0)
+			{
+				if (permIter->valid())
+	{
+					if (alter < permIter->actor())
+		{
+						lprobabilities[alter] = 0;
+					} else {
+						//            sum -= lprobabilities[alter];
+						lprobabilities[alter] /= total;
+						permIter->next();
+					}
+				} else {
+					lprobabilities[alter] = 0;
+				}
+			} else if (lpermitted[alter]) {
+				// sum -= lprobabilities[alter];
 			this->lprobabilities[alter] /= total;
+			} else {
+				this->lprobabilities[alter] = 0;
+			}
 		}
 	}
 	else
 	{
 		Rprintf("total = %f\n", total);
+		Rprintf("this actor = %d\n", (this->lego + 1) );
+		Rprintf("this period = %d\n", (this->period() + 1) );
+		// counting starts at 0
 		error("total probability non-positive");
 	}
+
+	// delete iter
+	if (permIter != 0) {
+		delete permIter;
+	}
 }
 
 /**
@@ -1160,27 +1397,31 @@ void NetworkVariable::calculateTieFlipProbabilities()
 void NetworkVariable::accumulateScores(int alter) const
 {
 	int m = this->m();
-	if (this->stepType() > 0)
+	int sumPermitted = 0;
+	Setting* curSetting = 0;
+	ITieIterator* permIter = 0;
+
+	if (this->stepType() != -1)
 	{
-		m = this->lsetting->size();
-	}
-	if (!this->oneModeNetwork())
+		curSetting = lsettings[stepType()];
+		m = curSetting->getPermittedSize();
+		sumPermitted = m;
+		permIter = curSetting->getPermittedSteps();
+	} else
 	{
+		if (!this->oneModeNetwork()) {
 		m++;
 	}
-	if (alter >= m)
-	{
-		Rprintf("this->n = %d this->m = %d m = %d alter = %d \n",
-				this->n(), this->m(), m, alter);
+		if (alter >= m) {
+			Rprintf("this->n = %d this->m = %d m = %d alter = %d \n", this->n(),
+					this->m(), m, alter);
 		error("alter too large");
 	}
-
-
-	int sumPermitted = 0;
 	for (int h = 0; h < m; h++)
 	{
 		if (this->lpermitted[h]) sumPermitted++;
 	}
+	}
 	if (sumPermitted <= 0)
 	{
 		error("nothing was permitted");
@@ -1200,27 +1441,33 @@ void NetworkVariable::accumulateScores(int alter) const
 					i, this->lego, alter, m);
 				error("nan score 41");
 			}
+			if (curSetting) {
+				permIter->reset();
+			}
 			// subtract sum over all permitted
 			int j = 0;
 			for (int alteri = 0; alteri < m; alteri++)
 			{
 				j = alteri;
-				if (this->stepType() > 0)
+				if (permIter)
 				{
-					j = (*this->lsetting)[alteri];
+					if (!permIter->valid())
+					{
+						error("iterator not valid");
+					}
+					j = permIter->actor();
+					permIter->next();
 				}
 				if (this->lpermitted[j])
 				{
 					score -=
 						this->levaluationEffectContribution[j][i] *
-						this->lprobabilities[alteri];
-						// TODO: check for settings model, 
-						// shouldn't alteri be replaced here by j?
+						this->lprobabilities[j];
 				}
 				if (R_IsNaN(score))
 				{
-					Rprintf("R_IsNaN error: i = %d ego = %d alter = %d alteri = %d m = %d\n",
-							i, this->lego, alter, alteri, m);
+					Rprintf("R_IsNaN error: i = %d ego = %d alter = %d j = %d m = %d\n",
+							i, this->lego, alter, j, m);
 					//						Rprintf("lpermitted: \n");
 					//						for (int hh = 0; hh < m; hh++)
 					//						{
@@ -1236,8 +1483,8 @@ void NetworkVariable::accumulateScores(int alter) const
 					//						}
 					Rprintf("R_IsNaN error: this->levaluationEffectContribution[j][i] = %f\n",
 							this->levaluationEffectContribution[j][i]);
-					Rprintf("R_IsNaN error: this->lprobabilities[alteri] = %f\n",
-							this->lprobabilities[alteri]);
+					Rprintf("R_IsNaN error: this->lprobabilities[j] = %f\n",
+							this->lprobabilities[j]);
 					error("nan score 1");
 				}
 			}
@@ -1263,19 +1510,28 @@ void NetworkVariable::accumulateScores(int alter) const
 				score += this->lendowmentEffectContribution[alter][i];
 			}
 
+			if (curSetting) {
+				permIter->reset();
+			}
+
 			// subtract sum over all permitted
 			int j = 0;
 			for (int alteri = 0; alteri < m; alteri++)
 			{
 				j = alteri;
-				if (this->stepType() > 0)
+				if (permIter)
 				{
-					j = (*this->lsetting)[alteri];
+					if (!permIter->valid())
+					{
+						error("iterator not valid");
+					}
+					j = permIter->actor();
+					permIter->next();
 				}
 				if (this->lpNetworkCache->outTieExists(j) && this->lpermitted[j])
 				{
 					score -= this->lendowmentEffectContribution[j][i]
-						* this->lprobabilities[alteri];
+						* this->lprobabilities[j];
 				}
 			}
 
@@ -1294,27 +1550,39 @@ void NetworkVariable::accumulateScores(int alter) const
 				score += this->lcreationEffectContribution[alter][i];
 			}
 
+			if (curSetting) {
+				permIter->reset();
+			}
+
 			// subtract sum over all permitted
 			int j = 0;
 			for (int alteri = 0; alteri < m; alteri++)
 			{
 				j = alteri;
-				if (this->stepType() > 0)
+				if (permIter)
 				{
-					j = (*this->lsetting)[alteri];
+					if (!permIter->valid())
+					{
+						error("iterator not valid");
+					}
+					j = permIter->actor();
+					permIter->next();
 				}
 				if (!this->lpNetworkCache->outTieExists(j) && this->lpermitted[j])
 				{
 					score -=
 						this->lcreationEffectContribution[j][i] *
-						this->lprobabilities[alteri];
+						this->lprobabilities[j];
 				}
 			}
 			this->pSimulation()->score(pEffect->pEffectInfo(),
 				this->pSimulation()->score(pEffect->pEffectInfo()) + score);
 		}
 	}
-	
+	if (permIter != 0)
+	{
+		delete permIter;
+	}
 }
 
 
@@ -2419,4 +2687,27 @@ bool NetworkVariable::diagonalMiniStep(int ego, int alter) const
 		(this->oneModeNetwork() && ego == alter);
 }
 
+void NetworkVariable::initializeSetting() {
+	NetworkLongitudinalData * pNetworkData =
+		dynamic_cast<NetworkLongitudinalData *>(this->pData());
+	Setting* setting = lsettings[stepType()];
+	string covariateName = pNetworkData->rSettingNames().at(this->stepType()).getCovarName();
+	if (pSimulation()->pData()->pConstantDyadicCovariate(covariateName)) {
+		setting->initDyadicSetting(
+				pSimulation()->pData()->pConstantDyadicCovariate(covariateName)->rRowValues(
+					ego()), ego());
+	}
+	if (pSimulation()->pData()->pChangingDyadicCovariate(covariateName)) {
+		setting->initDyadicSetting(
+				pSimulation()->pData()->pChangingDyadicCovariate(covariateName)->rRowValues(
+					ego(), period()), ego());
+	}
+	setting->initSetting(ego());
+}
+
+const Setting * NetworkVariable::setting(int i) const {
+	if (i >= numberSettings()) return 0;
+	return lsettings[i];
+}
+
 }
